@@ -5,10 +5,10 @@ use HTTP::Engine::Interface
         response_line => 1,
     }
 ;
+use HTTP::Engine::ClassCreator;
 
 use HTTP::Server::Simple 0.34;
 use HTTP::Server::Simple::CGI;
-use HTTP::Headers;
 
 has host => (
     is      => 'ro',
@@ -27,26 +27,24 @@ has net_server => (
     isa     => 'Str | Undef',
     default => undef,
 );
-no Moose;
 
 sub run {
     my ($self, ) = @_;
 
-    my $headers;
+    my $headers = HTTP::Headers::Fast->new;
     my %setup;
     my $server;
-    $server = Moose::Meta::Class
-        ->create_anon_class(
+    $server = HTTP::Engine::ClassCreator
+        ->create_anon(
             superclasses => ['HTTP::Server::Simple'],
             methods => {
-                setup => sub {
-                    shift; # $self;
-                    $headers = HTTP::Headers->new;
-                    %setup = @_;
-                },
                 headers => sub {
                     my ( $self, $args ) = @_;
-                    $headers->header(@$args) if @$args;
+                    $headers->header(@$args);
+                },
+                setup => sub {
+                    shift; # $self;
+                    %setup = @_;
                 },
                 handler    => sub {
                     my($host, $port) = $headers->header('Host') ?
@@ -81,7 +79,6 @@ sub run {
                 net_server => sub { $self->net_server },
             },
             cache => 1
-        )->new_object(
         )->new(
             $self->port
         );
