@@ -1,5 +1,5 @@
 package HTTP::Engine::RequestBuilder::CGI;
-use Moose;
+use Shika;
 
 with qw(
     HTTP::Engine::Role::RequestBuilder
@@ -7,6 +7,4 @@ with qw(
     HTTP::Engine::Role::RequestBuilder::HTTPBody
 );
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
 __PACKAGE__
