@@ -1,14 +1,14 @@
 package HTTP::Engine::Role::Interface;
 use strict;
-use Moose::Role;
-use HTTP::Engine::Types::Core qw( Handler );
+use Shika::Role;
+use HTTP::Engine::Types::Core qw(Handler);
 use HTTP::Engine::ResponseFinalizer;
 
 requires 'run';
 
 has request_handler => (
     is       => 'rw',
-    isa      => Handler,
+    isa      => 'Handler',
     coerce   => 1,
     required => 1,
 );
@@ -54,7 +54,7 @@ HTTP::Engine::Role::Interface - The Interface Role Definition
 =head1 SYNOPSIS
 
   package HTTP::Engine::Interface::CGI;
-  use Moose;
+  use Shika;
   with 'HTTP::Engine::Role::Interface';
 
 =head1 DESCRIPTION
