@@ -1,35 +1,13 @@
 package t::Utils;
-
-use strict;
-use warnings;
 use HTTP::Engine;
+use HTTP::Engine::ClassCreator;
 use HTTP::Request::AsCGI;
 use Test::TCP qw/test_tcp empty_port/;
-use HTTP::Engine::RequestBuilder::CGI;
-use HTTP::Engine::RequestBuilder::NoEnv;
-use File::Temp qw/tempdir/;
 
 use IO::Socket::INET;
 
-{
-    no warnings 'redefine';
-    my $tmpdir = tempdir( CLEANUP => 1 );
-    *HTTP::Engine::RequestBuilder::CGI::upload_tmp   = sub {
-        my $self = shift;
-        $self->{upload_tmp} ||= $tmpdir;
-        $self->{upload_tmp} = shift if @_;
-        $self->{upload_tmp};
-    };
-    *HTTP::Engine::RequestBuilder::NoEnv::upload_tmp = sub {
-        my $self = shift;
-        $self->{upload_tmp} ||= $tmpdir;
-        $self->{upload_tmp} = shift if @_;
-        $self->{upload_tmp};
-    };
-}
-
 use Sub::Exporter -setup => {
-    exports => [qw/ daemonize_all interfaces run_engine ok_response req running_interface/],
+    exports => [qw/ daemonize_all interfaces run_engine ok_response req /],
     groups  => { default => [':all'] }
 };
 
@@ -49,10 +27,6 @@ sub interfaces() {
     return @interfaces;
 }
 
-my $running_interface;
-
-sub running_interface { $running_interface }
-
 sub daemonize_all (&$@) {
     my($client, $codesrc) = @_;
 
@@ -65,7 +39,6 @@ sub daemonize_all (&$@) {
 
     my @interfaces = interfaces;
     for my $interface (@interfaces) {
-        $running_interface = $interface;
         my $client_cb = sub { $client->(@_, $interface) };
         if ($interface eq 'FCGI') {
             require t::FCGIUtils;
@@ -96,14 +69,14 @@ sub daemonize_all (&$@) {
 
                     $args{interface}->{args}->{request_handler} = $args{interface}->{request_handler};
                     my $interface = HTTP::Engine::Interface::CGI->new($args{interface}->{args});
-                    Moose::Util::apply_all_roles(
+                    Shika::apply_roles(
                         $interface->response_writer,
                         'HTTP::Engine::Role::ResponseWriter::ResponseLine'
                     );
                     delete $args{interface};
 
-                    Moose::Meta::Class
-                        ->create_anon_class(
+                    HTTP::Engine::ClassCreator
+                        ->create_anon(
                             superclasses => ['HTTP::Server::Simple::CGI'],
                             methods => {
                                 handler => sub {
@@ -113,8 +86,6 @@ sub daemonize_all (&$@) {
                                     )->run;
                                 },
                             },
-                            cache => 1
-                        )->new_object(
                         )->new(
                             $port
                         )->run;
@@ -157,21 +128,16 @@ sub ok_response {
 }
 
 my $BUILDER = do {
-    require HTTP::Engine::Role::RequestBuilder::ParseEnv; # XXX Moose 0.55_01 has a bug... please fix t/030/031
-
-    my $builder_meta = Moose::Meta::Class->create(
-        't::Utils::HTTPRequestBuilder' => (
-            superclass => 'Moose::Meta::Class',
-            roles => [qw(
-                HTTP::Engine::Role::RequestBuilder
-                HTTP::Engine::Role::RequestBuilder::ParseEnv
-                HTTP::Engine::Role::RequestBuilder::HTTPBody
-            )],
-            cache => 1,
-        )
-    );
-    $builder_meta->make_immutable;
-    $builder_meta->name->new(
+    {
+        package t::Utils::HTTPRequestBuilder;
+        use Shika;
+        with qw(
+            HTTP::Engine::Role::RequestBuilder
+            HTTP::Engine::Role::RequestBuilder::ParseEnv
+            HTTP::Engine::Role::RequestBuilder::HTTPBody
+        );
+    }
+    t::Utils::HTTPRequestBuilder->new(
         chunk_size => 1,
     );
 };
